==> kmp-tor-manager-android-1.3.0-sources.jar: androidMain/io/matthewnelson/kmp/tor/manager/internal/wrappers/-ResourceWrappers.kt <==
/*
 * Copyright (c) 2022 Matthew Nelson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/
package io.matthewnelson.kmp.tor.manager.internal.wrappers

import android.content.Context
import android.content.res.Resources
import android.graphics.drawable.Drawable
import android.os.Build

@JvmInline
internal value class ColorRes(val id: Int)

@Suppress("deprecation", "nothing_to_inline")
@Throws(Resources.NotFoundException::class)
internal inline fun ColorRes.retrieve(context: Context): Int {
    return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
        context.getColor(id)
    } else {
        context.resources.getColor(id)
    }
}

@JvmInline
internal value class DrawableRes(val id: Int)

@Suppress("deprecation", "nothing_to_inline")
@Throws(Resources.NotFoundException::class)
internal inline fun DrawableRes.retrieve(context: Context): Drawable? {
    return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
        context.getDrawable(id)
    } else {
        context.resources.getDrawable(id)
    }
}

==> kmp-tor-manager-android-1.3.4-sources.jar: androidMain/io/matthewnelson/kmp/tor/manager/internal/wrappers/-ResourceWrappers.kt <==
/*
 * Copyright (c) 2022 Matthew Nelson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/
package io.matthewnelson.kmp.tor.manager.internal.wrappers

import android.content.Context
import android.content.res.Resources
import android.graphics.drawable.Drawable
import android.os.Build

@JvmInline
internal value class ColorRes(val id: Int)

@Suppress("nothing_to_inline")
@Throws(Resources.NotFoundException::class)
internal inline fun ColorRes.retrieve(context: Context): Int {
    return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
        // API 23+
        context.getColor(id)
    } else {
        // API 22-
        @Suppress("DEPRECATION")
        context.resources.getColor(id)
    }
}

@JvmInline
internal value class DrawableRes(val id: Int)

@Suppress("nothing_to_inline")
@Throws(Resources.NotFoundException::class)
internal inline fun DrawableRes.retrieve(context: Context): Drawable? {
    return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
        // API 21+
        context.getDrawable(id)
    } else {
        // API 20-
        @Suppress("DEPRECATION")
        context.resources.getDrawable(id)
    }
}
